==> ssp-center-api-0.1.40-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

import cn.com.duiba.tuia.ssp.center.api.annotation.SensitiveInfo;
import cn.com.duiba.tuia.ssp.center.api.annotation.SensitiveType;

/**
 * ClassName:SlotStatisticsDataRsp <br/>
 * Function: 广告位数据统计 <br/>
 * Date: 2016年12月21日 下午2:09:30 <br/>
 *
 * @author ZFZ
 * @version
 * @since JDK 1.6
 * @see
 */
@SensitiveInfo(sensitiveFields = {"account"})
public class SlotStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = -6256880268510342548L;

    /** 广告位ID */
    private Long              slotId;

    /** 广告位名称 */
    private String            slotName;

    /** appName */
    private String            appName;

    /** 媒体ID */
    private Long              appId;

    /**系统平台*/
    private String           platform;

    /** 规格名称 */
    private String            msName;

    /** 当前日期 */
    private String            curDate;

    /** 用户ID */
     private Long             mediaId;

     /** 用户账号 */
    @SensitiveInfo(sensitiveType = SensitiveType.EMAIL)
    private String            account;
     
     /** 一级标签 */
     private String            tagName1;
     /** 二级标签 */
     private String            tagName2;
     /** 媒体流量标签 */
     private String            flowTagName;
     /** 流量分级标签 */
     private String            gradeTagName;
     /** 广告位性质标签 */
     private String            slotTagName;

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }


    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public String getTagName1() {
		return tagName1;
	}

	public void setTagName1(String tagName1) {
		this.tagName1 = tagName1;
	}

	public String getTagName2() {
		return tagName2;
	}

	public void setTagName2(String tagName2) {
		this.tagName2 = tagName2;
	}

	public String getFlowTagName() {
		return flowTagName;
	}

	public void setFlowTagName(String flowTagName) {
		this.flowTagName = flowTagName;
	}

	public String getSlotTagName() {
		return slotTagName;
	}

	public void setSlotTagName(String slotTagName) {
		this.slotTagName = slotTagName;
	}

	public String getGradeTagName() {
		return gradeTagName;
	}

	public void setGradeTagName(String gradeTagName) {
		this.gradeTagName = gradeTagName;
	}



}

==> ssp-center-api-0.9.52-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import cn.com.duiba.tuia.ssp.center.api.annotation.SensitiveInfo;
import cn.com.duiba.tuia.ssp.center.api.annotation.SensitiveType;
import cn.com.duiba.tuia.ssp.center.api.tool.DataMathUtil;
import com.google.common.collect.Maps;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.springframework.util.CollectionUtils;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * ClassName:SlotStatisticsDataRsp <br/>
 * Function: 广告位数据统计 <br/>
 * Date: 2016年12月21日 下午2:09:30 <br/>
 *
 * @author ZFZ
 * @version
 * @since JDK 1.6
 * @see
 */
@SensitiveInfo(sensitiveFields = {"account"})
public class SlotStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 8560372819967036329L;

    /** 广告位ID */
    private Long              slotId;

    /** 广告位名称 */
    private String            slotName;

    /** appName */
    private String            appName;

    /** 媒体ID */
    private Long              appId;

    /**系统平台*/
    private String           platform;

    /** 规格名称 */
    private String            msName;

    /** 当前日期 */
    private String            curDate;

    /** 用户ID */
     private Long             mediaId;

     /** 用户账号 */
    @SensitiveInfo(sensitiveType = SensitiveType.EMAIL)
    private String            account;
     
     /** 一级标签 */
     private String            tagName1;
     /** 二级标签 */
     private String            tagName2;
    /** 媒体流量标签 */
    private String            flowTagName;
    /** 流量分级标签 */
    private String            gradeTagName;
    private String              emoTagId;
    /** 网赚标签 */
    private String            emoTagName;
    /** 广告位性质标签 */
    private String            slotTagName;
    /** 子账号实际账号ID */
    private Long              subMediaId;

    /**生成时间**/
    private String           gmtCreate;

    /**
     * 预估得分
     */
    private String estimateScore;

    /**
     * 质量等级
     */
    private String estimateLevel;

    /**
     * 交易方式对应的标签，交易方式支持多选，所以是list类型
     */
    private List<MediaTagDto> tradeTypeTags;
    /**
     * 流量载体对应的标签，流量载体支持多选，所以是list类型
     */
    private List<MediaTagDto> carrierFlowTags;


    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }


    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public String getTagName1() {
		return tagName1;
	}

	public void setTagName1(String tagName1) {
		this.tagName1 = tagName1;
	}

	public String getTagName2() {
		return tagName2;
	}

	public void setTagName2(String tagName2) {
		this.tagName2 = tagName2;
	}

	public String getFlowTagName() {
		return flowTagName;
	}

	public void setFlowTagName(String flowTagName) {
		this.flowTagName = flowTagName;
	}

	public String getSlotTagName() {
		return slotTagName;
	}

	public void setSlotTagName(String slotTagName) {
		this.slotTagName = slotTagName;
	}

	public String getGradeTagName() {
		return gradeTagName;
	}

	public void setGradeTagName(String gradeTagName) {
		this.gradeTagName = gradeTagName;
	}

    public String getEmoTagName() {
        return emoTagName;
    }

    public void setEmoTagName(String emoTagName) {
        this.emoTagName = emoTagName;
    }

    public Long getSubMediaId() {
        return subMediaId;
    }

    public void setSubMediaId(Long subMediaId) {
        this.subMediaId = subMediaId;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getEstimateScore() {
        return estimateScore;
    }

    public void setEstimateScore(String estimateScore) {
        this.estimateScore = estimateScore;
    }

    public String getEstimateLevel() {
        return estimateLevel;
    }

    public void setEstimateLevel(String estimateLevel) {
        this.estimateLevel = estimateLevel;
    }

    public String getEmoTagId() {
        return emoTagId;
    }

    public void setEmoTagId(String emoTagId) {
        this.emoTagId = emoTagId;
    }

    public List<MediaTagDto> getTradeTypeTags() {
        return tradeTypeTags;
    }

    public void setTradeTypeTags(List<MediaTagDto> tradeTypeTags) {
        this.tradeTypeTags = tradeTypeTags;
    }

    public List<MediaTagDto> getCarrierFlowTags() {
        return carrierFlowTags;
    }

    public void setCarrierFlowTags(List<MediaTagDto> carrierFlowTags) {
        this.carrierFlowTags = carrierFlowTags;
    }

    public void setUpdateProportion(Boolean queryType, Map<Long,Integer> proportionMap){
        if (!queryType || CollectionUtils.isEmpty(proportionMap)){
            return;
        }
        DataMathUtil dataMathUtil=DataMathUtil.getInstance();
        Integer proportion=proportionMap.get(getSlotId());
        if (Objects.nonNull(proportion)){
            super.setReviseSlotSplitRatio(dataMathUtil.calculateDivideToFloat(Long.valueOf(proportion),100L,null));
        }
    }
}
